@@ -31,7 +31,8 @@ class AppFolioBase(AgencyBase):
             link = self.base_url + div.find('a', target="_blank")['href']
 
             rent = int(lookup['RENT'].replace('$', '').replace(',', ''))
-            [rawBed, rawBath] = lookup['Bed / Bath'].split('/ ')
+            # some listings do not have bed / bath provided
+            [rawBed, rawBath] = lookup.get('Bed / Bath', '0 / 0').split('/ ')
             rawBed = rawBed.split(' ')[0].strip()
             if rawBed == 'Studio':
                 is_studio = True
@@ -40,7 +41,9 @@ class AppFolioBase(AgencyBase):
                 is_studio = False
                 bed = int(rawBed)
             bath = float(rawBath.split(' ')[0].strip())
-            available_date = lookup['Available'].strip().lower()
+            available_date = lookup.get('Available', None)
+            if available_date:
+                available_date = available_date.strip().lower()
             if available_date == 'now':
                 # current date as mm/dd/yy
                 available_date = datetime.now().strftime('%m/%d/%y')
