@@ -1,11 +1,11 @@
 import requests
 import json
 from bs4 import BeautifulSoup
-from uiuc_apartments.shared import BaseAgency, Apartment
+from uiuc_apartments.shared import AgencyBase, Apartment
 
-class JSJ(BaseAgency):
+class JSJ(AgencyBase):
     url = 'https://jsjmanagement.com/on-campus'
-    agency = "JSJ Management"
+    name = "JSJ Management"
 
     def get_all(self):
         apartments = []
@@ -30,5 +30,5 @@ class JSJ(BaseAgency):
             avail_date = apartment['avail_date']
             # If avail_date is later than 08-01-2023, then available
             apartments.append(Apartment(address, price, bedrooms,
-                                        bathrooms, link, avail_date, self.agency, is_studio))
+                                        bathrooms, link, avail_date, self.name, is_studio))
         return apartments
\ No newline at end of file
