@@ -50,7 +50,7 @@ class Smith(AgencyBase):
             address = prop['street1'] + prop['street2'] + unit['unit'] + \
                 ', ' + prop['city'] + ', ' + prop['state'] + ' ' + prop['zip']
             rent = float(unit['marketrent'].replace(',', '').replace('$', ''))
-            bed = float(prop['bedrooms'])
+            bed = int(prop['bedrooms'])
             bath = float(prop['bathrooms'])
             is_studio = False
             link = 'https://smithapartments-cu.com/property-details/?pid=' + \
@@ -60,4 +60,4 @@ class Smith(AgencyBase):
 
             apartments.append(Apartment(address, rent, bed,
                                         bath, link, date_str, self.name, is_studio))
-        return apartments
\ No newline at end of file
+        return apartments
